@@ -206,7 +206,7 @@ https_init(const char *ikey, const char *skey,
         /* Initialize SSL context */
         SSL_library_init();
         SSL_load_error_strings();
-        OpenSSL_add_all_algorithms();
+        OpenSSL_add_ssl_algorithms();
 
         /* XXX - ape openssl s_client -rand for testing on ancient systems */
         if (!RAND_status()) {
@@ -358,7 +358,10 @@ https_open(struct https_request **reqp, const char *host)
                             sizeof(ctx->parse_buf))) <= 0) {
                         _BIO_wait(req->cbio, 5);
                 }
-                if (strncmp("HTTP/1.0 200", ctx->parse_buf, 12) != 0) {
+                /* Tolerate HTTP proxies that respond with an
+                   incorrect HTTP version number */
+                if ((strncmp("HTTP/1.0 200", ctx->parse_buf, 12) != 0)
+                    && (strncmp("HTTP/1.1 200", ctx->parse_buf, 12) != 0)) {
                         snprintf(ctx->errbuf, sizeof(ctx->errbuf),
                             "Proxy error: %s", ctx->parse_buf);
                         ctx->errstr = strtok(ctx->errbuf, "\r\n");
@@ -462,13 +465,9 @@ https_send(struct https_request *req, const char *method, const char *uri,
         } else {
                 BIO_printf(req->cbio, "Host: %s:%s\r\n", req->host, req->port);
         }
-        /* Add User-Agent header */
-        BIO_printf(req->cbio,
-                   "User-Agent: %s\r\n",
-                   ctx->useragent);
         /* Add signature */
         BIO_puts(req->cbio, "Authorization: Basic ");
-
+        
 	HMAC_CTX_init(&hmac);
 	HMAC_Init(&hmac, ctx->skey, strlen(ctx->skey), EVP_sha1());
 	HMAC_Update(&hmac, (unsigned char *)p, strlen(p));
